@@ -303,8 +303,6 @@ enum {
   SPVM_OPCODE_C_ID_SAY,
   SPVM_OPCODE_C_ID_WARN,
   SPVM_OPCODE_C_ID_DIE,
-  SPVM_OPCODE_C_ID_GET_DIE_ERROR_ID,
-  SPVM_OPCODE_C_ID_SET_DIE_ERROR_ID,
   SPVM_OPCODE_C_ID_CLEAR_EVAL_ERROR_ID,
   SPVM_OPCODE_C_ID_GET_EVAL_ERROR_ID,
   SPVM_OPCODE_C_ID_GET_CLASS_ID,
