@@ -957,7 +957,6 @@ use SPVM 'TestCase::$class_name';
 
 use SPVM '$class_name';
 use SPVM::$class_name;
-use SPVM 'Fn';
 
 my \$api = SPVM::api();
 
@@ -966,12 +965,9 @@ my \$start_memory_blocks_count = \$api->get_memory_blocks_count;
 ok(SPVM::TestCase::$class_name->test);
 
 # Version check
-{
-  my \$version_string = SPVM::Fn->get_version_string("$class_name");
-  is(\$SPVM::${class_name}::VERSION, \$version_string);
-}
+is(\$SPVM::${class_name}::VERSION, \$api->get_version_string("$class_name"));
 
-SPVM::Fn->destroy_runtime_permanent_vars;
+\$api->destroy_runtime_permanent_vars;
 
 my \$end_memory_blocks_count = \$api->get_memory_blocks_count;
 is(\$end_memory_blocks_count, \$start_memory_blocks_count);
